@@ -44,3 +44,8 @@ def experiment_type() -> str:
 def project() -> str:
     """Projects: 16 base62."""
     return lnschema_core.id.base62(n_char=16)
+
+
+def treatment() -> str:
+    """Projects: 12 base62."""
+    return lnschema_core.id.base62(n_char=12)
